@@ -7,6 +7,7 @@ MainWindow::MainWindow(QWidget *parent) :
     progress(tr("Setting up the theme, please wait..."), tr("Abort"), 0, 0, this),
     progress2(tr("Searching and importing fonts, please wait..."), tr("Abort"), 0, 0, this),
     progress3(tr("Reading settings..."), tr("Abort"), 0, 100, this),
+    progress4(tr("Restoring files, please wait..."), tr("Abort"), 0, 0, this),
     colors()
 {
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -541,7 +542,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-22<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-23<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -723,3 +724,44 @@ void MainWindow::delclicked()
 
     }
 }
+
+void MainWindow::on_actionRestore_theme_files_triggered()
+{
+    QMessageBox msgBox;
+    msgBox.setWindowTitle(tr("Theme Customizer - restore files"));
+    msgBox.setText(tr("Do you want to restore all original theme files?"));
+    msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+    msgBox.setDefaultButton(QMessageBox::Yes);
+    msgBox.button(msgBox.Yes)->setText(tr("Yes"));
+    msgBox.button(msgBox.No)->setText(tr("No"));
+    int ret = msgBox.exec();
+
+    if ( ret == QMessageBox::Yes ) {
+
+        QString varattu2;
+        varattu2 = tr("Restoring files from backup");
+        progress4.setWindowModality(Qt::WindowModal);
+        progress4.setWindowTitle(varattu2);
+        progress4.setCancelButton(0);
+        QStringList arguments2;
+        arguments2 << "restorefilespushed";
+        QProcess *process4 = new QProcess(this);
+        connect(process4, SIGNAL(finished(int)), this, SLOT(process2Finished2(int)));
+        process4->start("/sbin/launchcustomizer", arguments2);
+        progress4.show();
+
+    }
+}
+
+void MainWindow::process2Finished2(int)
+{
+    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'Restarting services, your screen will blink! After all is done, rebooting the device is recommended to reload all new values' uint32:0 string:'OK'");
+    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Restarting hildon-home...'");
+    system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
+    system("sleep 2");
+    system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
+    system("sleep 2 && killall hildon-status-menu");
+    system("sleep 2 && killall systemui");
+    system("sleep 2 && killall hildon-desktop");
+    system("killall theme-customizer");
+}
