@@ -40,6 +40,7 @@ private:
     QProgressDialog progress;
     QProgressDialog progress2;
     QProgressDialog progress3;
+    QProgressDialog progress4;
     QColorDialog colors;
     void readdirs();
     void readgtkrc();
@@ -62,6 +63,7 @@ private:
     managepresets* ManWin;
 
 private slots:
+    void on_actionRestore_theme_files_triggered();
     void loadclicked();
     void delclicked();
     void on_pushButton_4_clicked();
@@ -98,6 +100,7 @@ private slots:
     void on_pushButton_clicked();
     void processFinished(int exitCode);
     void process2Finished(int exitCode);
+    void process2Finished2(int exitCode);
 };
 
 #endif // MAINWINDOW_H
