@@ -8,6 +8,31 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Restore theme files</source>
+        <translation>Tiedostojen palautus</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Theme Customizer - restore files</source>
+        <translation>Theme Customizer - tiedostojen palautus</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restoring files, please wait...</source>
+        <translation>Palautetaan tiedostoja, odota...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Do you want to restore all original theme files?</source>
+        <translation>Haluatko palauttaa kaikki alkuperäiset teemojen tiedostot?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restoring files from backup</source>
+        <translation>Palautetaan varmuuskopiosta</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Reading settings...</source>
