@@ -8,6 +8,31 @@
         <source>Theme Customizer</source>
         <translation>Customiser le thème</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Restore theme files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restoring files, please wait...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Theme Customizer - restore files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Do you want to restore all original theme files?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restoring files from backup</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Reading settings...</source>
@@ -46,7 +71,7 @@
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Delete color preset?</source>
-        <translation>Effacer la présélection de couleur?</translation>
+        <translation>Effacer la présélection de couleurs?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
@@ -131,7 +156,7 @@
     <message>
         <location filename="mainwindow.ui" line="278"/>
         <source>Disabled font</source>
-        <translation>Désactivé</translation>
+        <translation>Désactivée</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="360"/>
@@ -243,7 +268,7 @@
     <message>
         <location filename="mainwindow.cpp" line="8"/>
         <source>Searching and importing fonts, please wait...</source>
-        <translation>Recherche et iportation des fontes, patientez svp...</translation>
+        <translation>Recherche et importation des fontes, patientez svp...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="349"/>
@@ -281,26 +306,26 @@
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Clock</source>
-        <translation>Horloge
- &amp; Alarme</translation>
+        <translation>Horloge et
+Alarmes</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>App Manager</source>
         <translation>Gestionnaire
- d&apos;application</translation>
+d&apos;application</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Media Player</source>
         <translation>Lecteur
- multimédia</translation>
+multimédia</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Lockscreen</source>
         <translation>Ecran de
- déverrouillage</translation>
+déverrouillage</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
@@ -366,7 +391,7 @@
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Original colors of current theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Couleur originale du thème actuel</translation>
     </message>
 </context>
 </TS>
