@@ -8,6 +8,31 @@
         <source>Theme Customizer</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Restore theme files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restoring files, please wait...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Theme Customizer - restore files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Do you want to restore all original theme files?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restoring files from backup</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Reading settings...</source>
@@ -62,7 +87,7 @@
         <location filename="mainwindow.cpp" line="0"/>
         <source>Save color preset</source>
         <translation type="unfinished"></translation>
-    </message>    
+    </message>
     <message>
         <location filename="mainwindow.ui" line="81"/>
         <source>Font</source>
